@@ -2,7 +2,7 @@
  * vout_vlc_wrapper.c: MacOS X plugin for vlc
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: vout_vlc_wrapper.m,v 1.2.2.1 2002/06/01 23:41:41 massiot Exp $
+ * $Id: vout_vlc_wrapper.m,v 1.2.2.2 2002/06/18 23:18:05 massiot Exp $
  *
  * Authors: Jon Lech Johansen <jon-vl@nanocrew.net> 
  *
@@ -32,6 +32,7 @@
 
 #include "video.h"
 #include "video_output.h"
+#include "audio_output.h"
 
 #include "interface.h"
 #include "intf_playlist.h"
@@ -116,6 +117,24 @@ static Vout_VLCWrapper *o_vout = nil;
 
     switch( key )
     {
+        case (unichar)0xf700: /* up-arrow */
+            if ( !p_main->p_intf->p_sys->b_mute
+                  && p_aout_bank->pp_aout[0]->i_volume + VOLUME_STEP
+                       <= VOLUME_MAX )
+            {
+                p_aout_bank->pp_aout[0]->i_volume += VOLUME_STEP;
+            }
+            break;
+
+        case (unichar)0xf701: /* down-arrow */
+            if ( !p_main->p_intf->p_sys->b_mute
+                  && p_aout_bank->pp_aout[0]->i_volume - VOLUME_STEP
+                       >= VOLUME_MIN )
+            {
+                p_aout_bank->pp_aout[0]->i_volume -= VOLUME_STEP;
+            }
+            break;
+
         case 'f': case 'F':
             p_vout->i_changes |= VOUT_FULLSCREEN_CHANGE;
             break;
